@@ -43,7 +43,7 @@ class CalendarEvent:
     def __init__(self, *args, **kwargs):
         for k, v in kwargs.items():
             if isinstance(v, bool):
-                setattr(self, k, 1 if v == True else 0)
+                setattr(self, k, 1 if v is True else 0)
             elif isinstance(v, datetime.datetime):
                 if isinstance(v, datetime.datetime):
                     r = v.isoformat()
