@@ -8,7 +8,7 @@ from django.core.files import File
 from django.db.models import BinaryField, BigIntegerField, CharField, TextField
 from django.forms import model_to_dict
 
-from isc_common import delAttr
+from isc_common import delAttr, setAttr
 from isc_common.common.UploadItemEx import UploadItemEx
 from isc_common.fields.files import FileFieldEx
 from isc_common.fields.name_field import NameField
@@ -118,29 +118,42 @@ class Crypto_file(AuditModel):
                 logger.warning(f'Removed file: {file_path} not finded.')
 
     @classmethod
-    def copy_file(cls, item):
-        if os.path.exists(item.real_file_name):
-            copyfile(src=item.real_file_name, dst=item.full_path)
+    def copy_file(cls, uploadItemEx):
+        from isc_common.models.images import Images
+
+        if os.path.exists(uploadItemEx.real_file_name):
+            copyfile(src=uploadItemEx.real_file_name, dst=uploadItemEx.full_path)
         else:
-            if item.tmp_file_name is not None and os.path.exists(item.tmp_file_name):
-                copyfile(src=item.tmp_file_name, dst=item.full_path)
-        with open(item.full_path, 'rb') as src:
+            if uploadItemEx.tmp_file_name is not None and os.path.exists(uploadItemEx.tmp_file_name):
+                copyfile(src=uploadItemEx.tmp_file_name, dst=uploadItemEx.full_path)
+
+        res = cls.objects.getOptional(real_name=uploadItemEx.real_file_name)
+        if res is not None:
+            return res, False
+
+        with open(uploadItemEx.full_path, 'rb') as src:
             fileObj = File(src)
-            res, created = cls.objects.update_or_create(
-                id=item.id,
-                defaults=dict(
-                    attfile=fileObj,
-                    file_store=item.get_path(fileObj.name),
-                    format=item.file_format,
-                    mime_type=item.file_mime_type,
-                    size=item.file_size,
-                    real_name=item.real_file_name,
-                )
+
+            defaults=dict(
+                attfile=fileObj,
+                file_store=uploadItemEx.get_path(fileObj.name),
+                format=uploadItemEx.file_format,
+                mime_type=uploadItemEx.file_mime_type,
+                size=uploadItemEx.file_size,
+                real_name=uploadItemEx.real_file_name,
             )
 
-        if item.tmp_file_name is not None and os.path.exists(item.tmp_file_name):
-            os.remove(item.tmp_file_name)
-            os.remove(item.full_path)
+            if issubclass(cls, Images):
+                setAttr(defaults, 'image_type', uploadItemEx.image_type)
+
+            res, created = cls.objects.update_or_create(
+                id=uploadItemEx.id,
+                defaults=defaults
+            )
+
+        if uploadItemEx.tmp_file_name is not None and os.path.exists(uploadItemEx.tmp_file_name):
+            os.remove(uploadItemEx.tmp_file_name)
+            os.remove(uploadItemEx.full_path)
 
         return res, created
 
@@ -156,30 +169,30 @@ class Crypto_file(AuditModel):
 
     @classmethod
     def create_update(cls, **kwargs):
-        item = UploadItemEx(**kwargs)
+        uploadItemEx = UploadItemEx(**kwargs)
 
         try:
-            if item.id is not None:
-                res = cls.objects.get(id=item.id)
-                action = cls.get_action(res=res, item=item)
+            if uploadItemEx.id is not None:
+                res = cls.objects.get(id=uploadItemEx.id)
+                action = cls.get_action(res=res, item=uploadItemEx)
             else:
-                if item.real_file_name is None:
+                if uploadItemEx.real_file_name is None:
                     raise Exception('Must be real_file_name or id')
                 else:
-                    res = cls.objects.get(real_name=item.real_file_name)
+                    res = cls.objects.get(real_name=uploadItemEx.real_file_name)
 
-                action = cls.get_action(res=res, item=item)
+                action = cls.get_action(res=res, item=uploadItemEx)
 
             if action is not None:
                 if action == 'update':
                     cls.remove_file(item=res)
 
-                return cls.copy_file(item=item)
+                return cls.copy_file(uploadItemEx=uploadItemEx)
             else:
                 return None, None
 
         except cls.DoesNotExist:
-            return cls.copy_file(item=item)
+            return cls.copy_file(uploadItemEx=uploadItemEx)
 
     def __str__(self):
         return f"{self.real_name}"
