@@ -118,7 +118,7 @@ def str_to_bool(s):
 
 
 def bool_to_jsBool(value):
-    if value == True:
+    if value is True:
         return "true"
     return "false"
 
@@ -286,7 +286,7 @@ class Stack:
         return Stack(self.stack)
 
     def find(self, function):
-        return list(filter(lambda x: function(x), self.stack)).copy()
+        return [item for item in self.stack if function(item)].copy()
 
     def exists(self, function):
         return len(self.find(function=function)) > 0
