@@ -12,14 +12,7 @@ logger = logging.getLogger(__name__)
 
 
 class User_phonesQuerySet(Model_phonesQuerySet):
-    def delete(self):
-        return super().delete()
-
-    def create(self, **kwargs):
-        return super().create(**kwargs)
-
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class User_phonesManager(AuditManager):
