@@ -1,7 +1,7 @@
 from django.urls import path
 
 from isc_common.auth.views import user
-from isc_common.auth.views.user import User_Add, User_Lookup, User_Info, User_Remove, User_Update, User_UploadPhoto
+from isc_common.auth.views.user import User_Add, User_Lookup, User_Info, User_Remove, User_Update
 from isc_common.auth.views.user_download_photo import user_download_photo
 
 urlpatterns = [
@@ -13,6 +13,5 @@ urlpatterns = [
     path('User/Remove', User_Remove),
     path('User/Lookup/', User_Lookup),
     path('User/Info/', User_Info),
-    path('User/UploadPhoto', User_UploadPhoto),
     path('User/DownloadPhoto/', user_download_photo),
 ]
