@@ -1,5 +1,4 @@
 from isc_common.auth.models.user import User, UserManager
-from isc_common.auth.models.user_upload_photo import DSResponse_User_UploadPhoto
 from isc_common.auth.models.user_view import UserView
 from isc_common.http.DSRequest import DSRequest
 from isc_common.http.DSResponse import DSResponseUpdate, DSResponseAdd, DSResponse, JsonResponseWithException
@@ -62,8 +61,3 @@ def User_Lookup(request):
 @JsonResponseWithException()
 def User_Info(request):
     return JsonResponse(DSResponse(request=request, data=User.objects.get_queryset().get_info(request=request), status=RPCResponseConstant.statusSuccess).response)
-
-
-@JsonResponseWithException()
-def User_UploadPhoto(request):
-    return JsonResponse(DSResponse_User_UploadPhoto(request).response)
