@@ -447,9 +447,9 @@ class CommonQuerySet(QuerySet):
             data = request.json.get('data')
             deleted = False
             for remove_field in remove_fields:
-                if delAttr(data, remove_field) == True:
+                if delAttr(data, remove_field) is True:
                     deleted = True
-            if deleted == True:
+            if deleted is True:
                 setAttr(request.json, 'data', data)
 
         self.alive_only = request.alive_only
@@ -665,7 +665,7 @@ class CommonManager(Manager):
                 for prop in propsArr:
                     _prop = data.get(prop)
 
-                    if _prop == True:
+                    if _prop is True:
                         props = TurnBitOn(props, idx)
                     else:
                         props = TurnBitOff(props, idx)
@@ -731,7 +731,7 @@ class CommonManager(Manager):
                         delAttr(cloned_data, 'parent')
                         setAttr(cloned_data, 'parent_id', parent)
                     res = super().filter(id=id).update(**cloned_data)
-                    print(f'res: {res}')
+                    # print(f'res: {res}')
                 else:
                     new_item = super().create(**cloned_data)
                     setAttr(_data, 'id', new_item.id)
@@ -753,7 +753,7 @@ class CommonManager(Manager):
 
         _old = _old1
 
-        for field_name in [field.name for field in old._meta.fields if field._unique == True]:
+        for field_name in [field.name for field in old._meta.fields if field._unique is True]:
             num = 1
             value = None
             while True:
