@@ -114,6 +114,21 @@ class AuditManager(CommonManager):
             if not callable(alternative):
                 raise Exception('alternative must be callable')
             return alternative()
+        except self.model.MultipleObjectsReturned as ex:
+            old_ids = kwargs.get('old_ids__overlap')
+            if old_ids is None:
+                raise ex
+            if len(old_ids) > 1:
+                raise ex
+
+            old_id=old_ids[0]
+
+            for item in self.filter(*args, **kwargs):
+                if len(item.old_ids) > 1:
+                    item.old_ids = list(filter(lambda x: x != old_id, item.old_ids))
+                    item.save()
+
+            return self.get(*args, **kwargs)
 
 
 class Manager(CommonManager):
