@@ -1,8 +1,5 @@
 import logging
 
-from django.contrib.postgres.fields import ArrayField
-from django.db.models import SmallIntegerField
-
 from crypto.models.crypto_file import Crypto_file, CryptoManager, CryptoQuerySet
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.image_types import Image_types
@@ -15,7 +12,13 @@ class ImagesQuerySet(CryptoQuerySet):
         return super().delete()
 
     def create(self, **kwargs):
-        return super().create(**kwargs)
+        if kwargs.get('real_name') is not None:
+            try:
+                return super().get(real_name=kwargs.get('real_name'))
+            except self.model.DoesNotExist:
+                return super().create(**kwargs)
+        else:
+            return super().create(**kwargs)
 
     def filter(self, *args, **kwargs):
         return super().filter(*args, **kwargs)
@@ -38,7 +41,6 @@ class ImagesManager(CryptoManager):
 
 class Images(Crypto_file):
     image_type = ForeignKeyProtect(Image_types)
-    sizes = ArrayField(SmallIntegerField(), null=True, blank=True)
     objects = ImagesManager()
 
     def __str__(self):
