@@ -25,7 +25,6 @@ class ProgressDroped(Exception):
 @contextmanager
 def managed_progress(qty, user, id, message='Обработано позиций', title='Обработано позиций', props=0, sendError=True):
     progress = Progress(id=id, qty=qty, user=user, message=message, title=title, props=props)
-
     try:
         yield progress
         progress.close()
@@ -33,7 +32,7 @@ def managed_progress(qty, user, id, message='Обработано позиций
         progress.close()
         if callable(progress.except_func):
             progress.except_func()
-        Deleted_progresses.objects.filter(id_progress=id, user=progress.user).delete()
+        Deleted_progresses.objects.filter(id_progress=id, user=user).delete()
         raise ex
     except Exception as ex:
         if callable(progress.except_func):
@@ -142,7 +141,7 @@ class Progress:
         self.id = id
         self.enable_ws_progress = IsBitOff(self.props, 1)
 
-        if self.enable_ws_progress == True:
+        if self.enable_ws_progress is True:
             if isinstance(user, int):
                 self.user = User.objects.get(id=user)
             elif isinstance(user, User):
@@ -165,7 +164,7 @@ class Progress:
                 user_id=self.user.id
             )
 
-            self.demand_str = self.message
+            self.demand_str = f'<h3>{self.message}</h3>'
 
             # if not self.check_exists():
 
@@ -203,7 +202,7 @@ class Progress:
         from isc_common.models.deleted_progresses import Deleted_progresses
 
         res = 0
-        if self.enable_ws_progress == True:
+        if self.enable_ws_progress is True:
             if self.progress is not None:
                 self.cnt += 1
                 self.progress.setCntDone(self.cnt, self.id)
