@@ -16,8 +16,8 @@ class Message_user_2_userQuerySet(AuditQuerySet):
 
 class Message_user_2_userManager(AuditManager):
 
-    @staticmethod
-    def getRecord(record):
+    @classmethod
+    def getRecord(cls, record):
         res = {
             'id': record.id,
             'user_reciver_id': record.user_reciver.id,
