@@ -75,17 +75,17 @@ class Chat_usersManager(AuditManager):
 
         with transaction.atomic():
             props = data.get('props')
-            if data.get('compulsory_reading') == True:
+            if data.get('compulsory_reading') is True:
                 props |= Chat_users.props.compulsory_reading
             else:
                 props &= ~Chat_users.props.compulsory_reading
 
-            if data.get('relevant') == True:
+            if data.get('relevant') is True:
                 props |= Chat_users.props.relevant
             else:
                 props &= ~Chat_users.props.relevant
 
-            if data.get('readonly') == True:
+            if data.get('readonly') is True:
                 props |= Chat_users.props.readonly
             else:
                 props &= ~Chat_users.props.readonly
